/*
 * Copyright 2019 TNG Technology Consulting GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tngtech.archunit.library.dependencies;

import com.tngtech.archunit.PublicAPI;
import com.tngtech.archunit.base.HasDescription;
import com.tngtech.archunit.core.domain.JavaClass;
import com.tngtech.archunit.core.domain.JavaClasses;

import static com.tngtech.archunit.PublicAPI.Usage.INHERITANCE;

/**
 * A mapping {@link JavaClass} -&gt; {@link SliceIdentifier} which defines how to partition
 * a set of {@link JavaClasses} into {@link Slices}. All classes that are mapped to the same
 * {@link SliceIdentifier} will belong to the same {@link Slice}.<br>
 * A {@link SliceAssignment} must provide a description to be used for the rule text of a rule
 * formed via {@link SlicesRuleDefinition}.
 */
@PublicAPI(usage = INHERITANCE)
public interface SliceAssignment extends HasDescription {
    SliceIdentifier getIdentifierOf(JavaClass javaClass);
}
